@@ -16,5 +16,5 @@ int main(int argc, char* argv[]) {
     newargv[i+extra_args] = argv[i];
   }
 
-  execv("/usr/bin/ruby", newargv);
+  execv(RUBY_BINARY, newargv);
 }
